@@ -13,11 +13,11 @@ from .utils.aws import (
     cancel_step,
     describe_cluster,
     describe_step,
-    download_erm_step_logs,
     get_step_state,
     list_steps,
     print_emr_log_files_lines,
     ssm_cluster,
+    download_emr_logs
 )
 from .utils.build import (
     build,
@@ -243,29 +243,7 @@ class Cli:
 
         """
         pprint(describe_step(cluster_name, step_id, name, state))
-
-    def download_logs(
-        self,
-        out_dir="./logs",
-        step_id="",
-        cluster_name="",
-        name="*{env_name}*",
-        state="*",
-    ):
-        """
-
-        Args:
-          step_id: (Default value = "")
-          out_dir: (Default value = "./logs")
-          cluster_name: (Default value = "")
-          name: (Default value = "*{env_name}*")
-          state: (Default value = "*")
-
-        Returns:
-
-        """
-        download_erm_step_logs(cluster_name, step_id, name, state, out_dir=out_dir)
-
+    
     def logs(
         self,
         log_type,
@@ -274,7 +252,7 @@ class Cli:
         cluster_name="",
         name="*{env_name}*",
         state="*",
-        out_dir="./logs",
+        out_dir="logs",
     ):
         """
 
@@ -302,7 +280,7 @@ class Cli:
         cluster_name="",
         name="*{env_name}*",
         state="*",
-        out_dir="./logs",
+        out_dir="logs",
     ):
         """
 
@@ -326,7 +304,7 @@ class Cli:
         cluster_name="",
         name="*{env_name}*",
         state="*",
-        out_dir="./logs",
+        out_dir="logs",
     ):
         """
 
@@ -485,6 +463,16 @@ class Cli:
 
         """
         raise ValueError("This features is not available yet.")
+    
+    def download_logs(
+            self,
+            out_dir="logs",
+            step_id="",
+            cluster_name="",
+            name="*{env_name}*",
+            state="*",
+        ):
+        return download_emr_logs(cluster_name, step_id, name, state, out_dir)
 
 
 def main():
