@@ -9,13 +9,13 @@ from typing import Dict
 
 import tomlkit
 
+REQUIRED_PARAM = ["s3-staging-dir", "cluster-name", "stage", "region"]
+
 DEFAULT_CONFIG_TEMPLATE = {
     "cluster-name": "EDA",
     "s3-staging-dir": "s3://<bucket-name>/<your-staging-directory>",
     "stage": "dev",
     "date-time": "%Y-%m-%dT%H-%M-%S",
-    "emr-master-pypath": "/usr/bin/python3",
-    "emr-python-version": "3.7.6",
     "region": "eu-west-1",
 }
 
@@ -172,6 +172,10 @@ def _pyproject_toml_exists(pyproj_path: str = "./pyproject.toml"):
       pyproj_path: str:  (Default value = "./pyproject.toml")
       pyproj_path: str:  (Default value = "./pyproject.toml")
       pyproj_path: str:  (Default value = "./pyproject.toml")
+      pyproj_path: str:  (Default value = "./pyproject.toml")
+      pyproj_path: str:  (Default value = "./pyproject.toml")
+      pyproj_path: str:  (Default value = "./pyproject.toml")
+      pyproj_path: str:  (Default value = "./pyproject.toml")
 
     Returns:
 
@@ -197,6 +201,10 @@ def _get_pyproject_toml(pyproj_path: str = "./pyproject.toml") -> Dict[str, str]
       pyproj_path: str:  (Default value = "./pyproject.toml")
       pyproj_path: str:  (Default value = "./pyproject.toml")
       pyproj_path: str:  (Default value = "./pyproject.toml")
+      pyproj_path: str:  (Default value = "./pyproject.toml")
+      pyproj_path: str:  (Default value = "./pyproject.toml")
+      pyproj_path: str:  (Default value = "./pyproject.toml")
+      pyproj_path: str:  (Default value = "./pyproject.toml")
 
     Returns:
 
@@ -244,6 +252,14 @@ def _write_pyproject_toml(file_contents: dict, pyproj_path: str = "./pyproject.t
       pyproj_path: str:  (Default value = "./pyproject.toml")
       file_contents: dict:
       pyproj_path: str:  (Default value = "./pyproject.toml")
+      file_contents: dict:
+      pyproj_path: str:  (Default value = "./pyproject.toml")
+      file_contents: dict:
+      pyproj_path: str:  (Default value = "./pyproject.toml")
+      file_contents: dict:
+      pyproj_path: str:  (Default value = "./pyproject.toml")
+      file_contents: dict:
+      pyproj_path: str:  (Default value = "./pyproject.toml")
 
     Returns:
 
@@ -346,17 +362,20 @@ def cprint(text, color="OKCYAN"):
     return print(color_text(text, color))
 
 
-def init_pyemr_param(cluster_name, stage_dir):
+def init_pyemr_param(cluster_name, s3_stage_dir, stage, region):
     """Append EMR pack aparameters to the project toml
 
     Args:
       cluster_name:
       stage_dir:
+      s3_stage_dir:
+      stage:
+      region:
 
     Returns:
 
     """
-    cprint("\npyemr configs: \n")
+
     tml = _get_pyproject_toml()
 
     if "tool" not in tml:
@@ -365,18 +384,26 @@ def init_pyemr_param(cluster_name, stage_dir):
     if "pyemr" not in tml["tool"]:
         tml["tool"]["pyemr"] = {}
 
-    if cluster_name is not None and cluster_name != "":
+    if cluster_name:
         tml["tool"]["pyemr"]["cluster-name"] = cluster_name
 
-    if stage_dir is not None and stage_dir != "":
-        tml["tool"]["pyemr"]["s3-staging-dir"] = stage_dir
+    if s3_stage_dir:
+        tml["tool"]["pyemr"]["s3-staging-dir"] = s3_stage_dir
+
+    if stage:
+        tml["tool"]["pyemr"]["stage"] = stage
+
+    if region:
+        tml["tool"]["pyemr"]["region"] = region
 
     for variable_name, default_value in DEFAULT_CONFIG_TEMPLATE.items():
         if variable_name not in tml["tool"]["pyemr"]:
-            value = cinput(variable_name, default_value)
+            if variable_name in REQUIRED_PARAM:
+                value = cinput(variable_name, default_value)
+            else:
+                value = default_value
             tml["tool"]["pyemr"][variable_name] = value
 
-    print("")
     print("[tool.pyemr]")
     print(tomlkit.dumps(tml["tool"]["pyemr"]))
 
@@ -471,88 +498,59 @@ def add_scr_package():
     add_packages_to_toml(package_path)
 
 
-def init_pyemr(cluster_name, stage_dir):
+def init_pyemr(project_name, cluster_name, s3_stage_dir, stage, region):
     """
 
     Args:
       cluster_name:
       stage_dir:
+      project_name:
+      s3_stage_dir:
+      stage:
+      region:
 
     Returns:
 
     """
 
+    dep = [
+        f"--dependency={name}={version}"
+        for name, version in DEFAULT_DEPENDENCIES.items()
+    ]
+
     if not _pyproject_toml_exists():
-        proc = subprocess.Popen(["poetry", "init", "--python=>=3.7,<3.10"])
+        if project_name is None or project_name == "":
+            project_name = cinput("Project Name", "tmp")
+        args = [
+            "poetry",
+            "init",
+            "--python=>=3.7,<3.10",
+            "-n",
+            "--name",
+            project_name,
+            "--quiet",
+        ] + dep
+        proc = subprocess.Popen(args)
         proc.communicate()
 
     # install default dependencies
-    add_dependencies(DEFAULT_DEPENDENCIES)
+    # add_dependencies(DEFAULT_DEPENDENCIES)
     add_scr_package()
-    init_pyemr_param(cluster_name, stage_dir)
+    init_pyemr_param(cluster_name, s3_stage_dir, stage, region)
     create_git_ignore()
+    os.system("open pyproject.toml")
 
 
 """
-sudo pyspark \
---conf spark.pyspark.python=python3 \
---conf spark.pyspark.virtualenv.enabled=true \
---conf spark.pyspark.virtualenv.type=native \
---conf spark.pyspark.virtualenv.bin.path=/usr/bin/virtualenv
-
-"""
-
-
-"""
-sudo PYARROW_IGNORE_TIMEZONE=1 \
-PYSPARK_DRIVER_PYTHON={venv_path}/bin/python3 \
-PYSPARK_PYTHON={venv_path}/bin/python3 \
-spark-submit \
---deploy-mode client \
-{s3_script_path}
-"""
-
-"""
-sudo PYARROW_IGNORE_TIMEZONE=1 \
-PYSPARK_PYTHON=python3 \
-spark-submit \
---conf spark.yarn.appMasterEnv.PYSPARK_PYTHON=/usr/bin/python3 \
---conf spark.pyspark.python=python3 \
---conf spark.pyspark.virtualenv.enabled=true \
---conf spark.pyspark.virtualenv.type=native \
---conf spark.pyspark.virtualenv.bin.path=/usr/bin/virtualenv \
---conf spark.app.id=1231552 \
---master yarn \
---deploy-mode cluster \
-s3://anghami.firewood/ml/customerIntelligence/stage=dev/version=0.1.0/code/datetime=2021-12-12T22-21-05/script2.py
-
-
-
-spark-submit \
---conf spark.yarn.appMasterEnv.PYSPARK_PYTHON=./environment/bin/python \
---conf spark.yarn.dist.archives=hdfs:///share/python-envs/${env}.tar.gz#environment \
---master yarn \
---deploy-mode cluster \
-test.py
-
-
-
-spark-submit \
---conf spark.yarn.appMasterEnv.PYSPARK_PYTHON=./environment/bin/python3 \
---conf spark.yarn.dist.archives=hdfs:///share/python-envs/${env}.tar.gz#environment \
---master yarn \
---deploy-mode cluster \
-s3://anghami.firewood/ml/customerIntelligence/stage=dev/version=0.1.0/code/datetime=2021-12-12T21-20-24/script.py
-
-
-
-spark-submit \
---conf spark.yarn.appMasterEnv.PYSPARK_PYTHON=./environment/bin/python3 \
---conf spark.yarn.dist.archives=s3://anghami.firewood/ml/customerIntelligence/stage=dev/version=0.1.0/code/datetime=2021-12-12T21-20-24/python3-venv.tar.g#environment \
---master yarn \
---deploy-mode cluster \
-s3://anghami.firewood/ml/customerIntelligence/stage=dev/version=0.1.0/code/datetime=2021-12-12T21-20-24/script.py
-
-
-
+    --project_name=PROJECT_NAME
+        Default: ''
+    --cluster_name=CLUSTER_NAME
+        Default: ''
+        (Default value = '')
+    --s3_stage_dir=S3_STAGE_DIR
+        Default: ''
+    --stage=STAGE
+        Default: ''
+    --region=REGION
+        Default: ''
 """
